eric7/Plugins/PluginWizardE5MessageBox.py

branch
eric7
changeset 8356
68ec9c3d4de5
parent 8318
962bce857696
child 8358
144a6b854f70
diff -r 8a7677a63c8d -r 68ec9c3d4de5 eric7/Plugins/PluginWizardE5MessageBox.py
--- a/eric7/Plugins/PluginWizardE5MessageBox.py	Sat May 22 17:01:51 2021 +0200
+++ b/eric7/Plugins/PluginWizardE5MessageBox.py	Sat May 22 18:51:46 2021 +0200
@@ -4,28 +4,28 @@
 #
 
 """
-Module implementing the E5MessageBox wizard plugin.
+Module implementing the EricMessageBox wizard plugin.
 """
 
 from PyQt6.QtCore import QObject
 from PyQt6.QtWidgets import QDialog
 
-from E5Gui.E5Application import e5App
-from E5Gui.E5Action import E5Action
-from E5Gui import E5MessageBox
+from E5Gui.EricApplication import ericApp
+from E5Gui.EricAction import EricAction
+from E5Gui import EricMessageBox
 
 import UI.Info
 
 # Start-Of-Header
-name = "E5MessageBox Wizard Plugin"
+name = "EricMessageBox Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
 version = UI.Info.VersionOnly
 className = "E5MessageBoxWizard"
 packageName = "__core__"
-shortDescription = "Show the E5MessageBox wizard."
-longDescription = """This plugin shows the E5MessageBox wizard."""
+shortDescription = "Show the EricMessageBox wizard."
+longDescription = """This plugin shows the EricMessageBox wizard."""
 pyqtApi = 2
 # End-Of-Header
 
@@ -34,7 +34,7 @@
 
 class E5MessageBoxWizard(QObject):
     """
     Class implementing the E5MessageBox wizard plugin.
     """
     def __init__(self, ui):
         """
@@ -63,26 +63,26 @@
         menu = self.__ui.getMenu("wizards")
         if menu:
             menu.removeAction(self.action)
-        self.__ui.removeE5Actions([self.action], 'wizards')
+        self.__ui.removeEricActions([self.action], 'wizards')
     
     def __initAction(self):
         """
         Private method to initialize the action.
         """
-        self.action = E5Action(
-            self.tr('E5MessageBox Wizard'),
-            self.tr('&E5MessageBox Wizard...'), 0, 0, self,
+        self.action = EricAction(
+            self.tr('EricMessageBox Wizard'),
+            self.tr('&EricMessageBox Wizard...'), 0, 0, self,
             'wizards_e5messagebox')
-        self.action.setStatusTip(self.tr('E5MessageBox Wizard'))
+        self.action.setStatusTip(self.tr('EricMessageBox Wizard'))
         self.action.setWhatsThis(self.tr(
-            """<b>E5MessageBox Wizard</b>"""
+            """<b>EricMessageBox Wizard</b>"""
             """<p>This wizard opens a dialog for entering all the parameters"""
-            """ needed to create an E5MessageBox. The generated code is"""
+            """ needed to create an EricMessageBox. The generated code is"""
             """ inserted at the current cursor position.</p>"""
         ))
         self.action.triggered.connect(self.__handle)
         
-        self.__ui.addE5Actions([self.action], 'wizards')
+        self.__ui.addEricActions([self.action], 'wizards')
 
     def __initMenu(self):
         """
@@ -118,10 +118,10 @@
         """
         Private method to handle the wizards action.
         """
-        editor = e5App().getObject("ViewManager").activeWindow()
+        editor = ericApp().getObject("ViewManager").activeWindow()
         
         if editor is None:
-            E5MessageBox.critical(
+            EricMessageBox.critical(
                 self.__ui,
                 self.tr('No current editor'),
                 self.tr('Please open or create a file first.'))
@@ -34,7 +34,7 @@
 class E5MessageBoxWizard(QObject):
     """
-    Class implementing the E5MessageBox wizard plugin.
+    Class implementing the EricMessageBox wizard plugin.
     """
     def __init__(self, ui):

eric ide

mercurial